==> aws-lambda-requests-wrapper-0.1.4.tar.gz: aws-lambda-requests-wrapper-0.1.4/README.md <==
# AWS Lambda Requests Wrapper

Request/Response wrapper for AWS Lambda with API Gateway

[![Build](https://github.com/DeveloperRSquared/aws-lambda-requests-wrapper/actions/workflows/build.yaml/badge.svg)](https://github.com/DeveloperRSquared/aws-lambda-requests-wrapper/actions/workflows/build.yaml)
[![Deploy](https://github.com/DeveloperRSquared/aws-lambda-requests-wrapper/actions/workflows/deploy.yaml/badge.svg)](https://github.com/DeveloperRSquared/aws-lambda-requests-wrapper/actions/workflows/deploy.yaml)

[![Python 3.7+](https://img.shields.io/badge/python-3.7+-brightgreen.svg)](#aws-lambda-requests-wrapper)
[![PyPI - License](https://img.shields.io/pypi/l/aws-lambda-requests-wrapper.svg)](LICENSE)
[![PyPI - Version](https://img.shields.io/pypi/v/aws-lambda-requests-wrapper.svg)](https://pypi.org/project/aws-lambda-requests-wrapper)

[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)

## Setup

```sh
poetry install
pre-commit install
pre-commit run --all-files
```

## Contributing

Contributions are welcome via pull requests.

## Issues

If you encounter any problems, please file an
[issue](https://github.com/DeveloperRSquared/aws-lambda-requests-wrapper/issues) along with a
detailed description.

==> aws-lambda-requests-wrapper-0.1.6.tar.gz: aws-lambda-requests-wrapper-0.1.6/README.md <==
# AWS Lambda Requests Wrapper

Request/Response wrapper for AWS Lambda with API Gateway

[![Build](https://github.com/DeveloperRSquared/aws-lambda-requests-wrapper/actions/workflows/build.yaml/badge.svg)](https://github.com/DeveloperRSquared/aws-lambda-requests-wrapper/actions/workflows/build.yaml)
[![Deploy](https://github.com/DeveloperRSquared/aws-lambda-requests-wrapper/actions/workflows/deploy.yaml/badge.svg)](https://github.com/DeveloperRSquared/aws-lambda-requests-wrapper/actions/workflows/deploy.yaml)

[![Python 3.7+](https://img.shields.io/badge/python-3.7+-brightgreen.svg)](#aws-lambda-requests-wrapper)
[![PyPI - License](https://img.shields.io/pypi/l/aws-lambda-requests-wrapper.svg)](LICENSE)
[![PyPI - Version](https://img.shields.io/pypi/v/aws-lambda-requests-wrapper.svg)](https://pypi.org/project/aws-lambda-requests-wrapper)

[![codecov](https://codecov.io/gh/DeveloperRSquared/aws-lambda-requests-wrapper/branch/main/graph/badge.svg?token=UI5ZDDDXXB)](https://codecov.io/gh/DeveloperRSquared/aws-lambda-requests-wrapper)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)

## Setup

```sh
poetry install
pre-commit install
pre-commit run --all-files
```

## Contributing

Contributions are welcome via pull requests.

## Issues

If you encounter any problems, please file an
[issue](https://github.com/DeveloperRSquared/aws-lambda-requests-wrapper/issues) along with a
detailed description.
